@@ -17,9 +17,10 @@ impl<'de, const L: usize> Deserialize<'de> for String<L> {
     where
         D: Deserializer<'de>,
     {
-        let s: &str = Deserialize::deserialize(deserializer)?;
+        // FIXME: try to make this a &str
+        let s: std::string::String = Deserialize::deserialize(deserializer)?;
 
-        Self::try_from(s)
+        Self::try_from(s.as_str())
             .map_err(|e| D::Error::custom(format!("Expected a String with len {}, got {}", L, e)))
     }
 }
